---
name: Bug report/ 错误报告 about: Create a report to help us improve/ 创建一个报告以帮助我们了解情况 title: Bugs labels: ''
assignees: ''

---

**Describe the bug / 问题描述**
> 请在此处描述问题

**To Reproduce / 复现步骤 **

Steps to reproduce the behavior:

1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior / 期望结果**
A clear and concise description of what you expected to happen.

**Screenshots / 截图**

If applicable, add screenshots to help explain your problem./如果可能请将截图放于此处

**Environment/ 你的运行环境**

- OS: [e.g. Linux]
- Python Version: [e.g.Python36]
- ctpbee Version: [e.g. 0.50]
